==> v4.4.6.tar.gz: doomretro-4.4.6/src/i_winmusic.h <==
﻿/*
========================================================================

                           D O O M  R e t r o
         The classic, refined DOOM source port. For Windows PC.

========================================================================

  Copyright © 1993-2022 by id Software LLC, a ZeniMax Media company.
  Copyright © 2013-2022 by Brad Harding <mailto:brad@doomretro.com>.

  DOOM Retro is a fork of Chocolate DOOM. For a list of credits, see
  <https://github.com/bradharding/doomretro/wiki/CREDITS>.

  This file is a part of DOOM Retro.

  DOOM Retro is free software: you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation, either version 3 of the license, or (at your
  option) any later version.

  DOOM Retro is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with DOOM Retro. If not, see <https://www.gnu.org/licenses/>.

  DOOM is a registered trademark of id Software LLC, a ZeniMax Media
  company, in the US and/or other countries, and is used without
  permission. All other trademarks are the property of their respective
  holders. DOOM Retro is in no way affiliated with nor endorsed by
  id Software.

========================================================================
*/

#if defined(_WIN32)

#if !defined(__I_WINMUSIC_H__)
#define __I_WINMUSIC_H__

#include "doomtype.h"

dboolean I_Windows_InitMusic(void);
void I_Windows_PlaySong(dboolean looping);
void I_Windows_PauseSong(void);
void I_Windows_ResumeSong(void);
void I_Windows_StopSong(void);
void I_Windows_SetMusicVolume(int volume);
void I_Windows_RegisterSong(void *data, int size);
void I_Windows_UnregisterSong(void);
void I_Windows_ShutdownMusic(void);

#endif

#endif

==> v4.5.tar.gz: doomretro-4.5/src/i_winmusic.h <==
﻿/*
========================================================================

                           D O O M  R e t r o
         The classic, refined DOOM source port. For Windows PC.

========================================================================

  Copyright © 1993-2022 by id Software LLC, a ZeniMax Media company.
  Copyright © 2013-2022 by Brad Harding <mailto:brad@doomretro.com>.

  DOOM Retro is a fork of Chocolate DOOM. For a list of acknowledgments,
  see <https://github.com/bradharding/doomretro/wiki/ACKNOWLEDGMENTS>.

  This file is a part of DOOM Retro.

  DOOM Retro is free software: you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation, either version 3 of the license, or (at your
  option) any later version.

  DOOM Retro is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with DOOM Retro. If not, see <https://www.gnu.org/licenses/>.

  DOOM is a registered trademark of id Software LLC, a ZeniMax Media
  company, in the US and/or other countries, and is used without
  permission. All other trademarks are the property of their respective
  holders. DOOM Retro is in no way affiliated with nor endorsed by
  id Software.

========================================================================
*/

#if defined(_WIN32)

#pragma once

#include "doomtype.h"

bool I_Windows_InitMusic(void);
void I_Windows_PlaySong(bool looping);
void I_Windows_PauseSong(void);
void I_Windows_ResumeSong(void);
void I_Windows_StopSong(void);
void I_Windows_SetMusicVolume(int volume);
void I_Windows_RegisterSong(void *data, int size);
void I_Windows_UnregisterSong(void);
void I_Windows_ShutdownMusic(void);

#endif
